graphcal_iv: Graphical calculation of clearance and volume of distribution...

View source: R/run_graphcal.R

graphcal_ivR Documentation

Graphical calculation of clearance and volume of distribution (IV route)

Description

Estimates clearance (CL), volume of distribution (Vd), terminal slope (lambdaz), and extrapolated concentration at time zero (C0exp) from intravenous pharmacokinetic data using graphical methods.

Usage

graphcal_iv(dat, dose = 1, ...)

Arguments

dat

A data frame containing TIME (time after dosing) and DV (observed concentration).

dose

Administered dose amount. Defaults to 1.

...

Additional arguments passed to force_find_lambdaz().

Details

Terminal slope (lambdaz) is estimated using force_find_lambdaz(), which applies an automated phase selection strategy with fallback regression when required.

Value

A list containing graphical estimates of CL, Vd, lambda_z, and C0exp.

Author(s)

Zhonghui Huang

See Also

force_find_lambdaz

Examples

dat <- data.frame(TIME = c(0.5, 1, 2, 4, 6, 8, 10),
                  DV = c(12, 8, 5, 3, 2, 1.5, 1))
graphcal_iv(dat, dose = 100)


nlmixr2autoinit documentation built on Nov. 14, 2025, 1:07 a.m.