mark_dose_number: Mark dose number

View source: R/calculate_tad.R

mark_dose_numberR Documentation

Mark dose number

Description

Assigns sequential dose numbers based on dosing events (EVID) within each subject.

Usage

mark_dose_number(dat)

Arguments

dat

A data frame containing raw time–concentration data in the standard nlmixr2 format.

Value

A modified data frame with an added column named dose_number, indicating the sequential dose count within each subject and reset group.

Author(s)

Zhonghui Huang

Examples

mark_dose_number(Bolus_1CPT)
mark_dose_number(Infusion_1CPT)
mark_dose_number(Oral_1CPT)


nlmixr2autoinit documentation built on Nov. 14, 2025, 1:07 a.m.