| run_npd_1cmpt_mm_iv | R Documentation |
Fits a one-compartment intravenous pharmacokinetic model with Michaelis-Menten elimination using a naive pooled data approach and evaluates model performance based on prediction error metrics.
run_npd_1cmpt_mm_iv(
dat,
est.method = "nls",
npdmm_inputvmax = exp(1),
npdmm_inputkm = exp(1),
npdmm_inputcl = exp(1),
npdmm_inputvd = exp(1),
input.add = 1,
km_threshold = FALSE
)
dat |
A data frame containing pharmacokinetic data in standard nlmixr2 format. |
est.method |
Estimation method used in nlmixr2. Defaults to "nls". |
npdmm_inputvmax |
Initial estimate for Vmax. Defaults to exp(1), corresponding to a log-scale value of 1. |
npdmm_inputkm |
Initial estimate for Km. Defaults to exp(1), corresponding to a log-scale value of 1. |
npdmm_inputcl |
Initial estimate for clearance (CL). Defaults to exp(1) , corresponding to a log-scale value of 1. |
npdmm_inputvd |
Initial estimate for volume of distribution (Vd). Defaults to exp(1), corresponding to a log-scale value of 1. |
input.add |
Additive error term. Defaults to 1. |
km_threshold |
Logical value. If TRUE, initial estimates for Vmax and Km are calculated based on the maximum observed concentration. |
Rows where EVID == 2 are excluded before model fitting. The model is
fitted using Fit_1cmpt_mm_iv. When km_threshold = TRUE, initial estimates
for Vmax and Km are derived from the dataset to provide a representative
starting point for nonlinear elimination.
A list containing parameter estimates and prediction error metrics.
Zhonghui Huang
Fit_1cmpt_mm_iv
run_npd_1cmpt_mm_iv(
dat = Bolus_1CPT,
npdmm_inputcl = 4,
npdmm_inputvd = 70,
km_threshold = TRUE
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.