View source: R/npd_modelcodes.R
| Fit_2cmpt_oral | R Documentation |
Fits oral pharmacokinetic data to a two-compartment model with first-order absorption and first-order elimination using the naive pooled data approach. Supports multiple estimation methods available in nlmixr2, and optionally returns only predicted concentrations to support simulation workflows.
Fit_2cmpt_oral(
data,
est.method,
input.ka,
input.cl,
input.vc2cmpt,
input.vp2cmpt,
input.q2cmpt,
input.add,
return.pred.only = FALSE,
...
)
data |
A data frame containing oral pharmacokinetic data formatted for nlmixr2, |
est.method |
Estimation method to use in nlmixr2, one of:
|
input.ka |
Initial estimate of the absorption rate constant (ka). |
input.cl |
Initial estimate of clearance (CL). |
input.vc2cmpt |
Initial estimate of central volume of distribution (V1). |
input.vp2cmpt |
Initial estimate of peripheral volume of distribution (V2). |
input.q2cmpt |
Initial estimate of inter-compartmental clearance (Q). |
input.add |
Initial estimate of the additive residual error. |
return.pred.only |
Logical; if |
... |
Additional arguments passed to |
If return.pred.only = TRUE, returns a data.frame
with a single column cp (predicted concentrations).
Otherwise, returns a fitted model object produced by nlmixr2.
Zhonghui Huang
dat <- Oral_2CPT
# Fit using 'nls'
Fit_2cmpt_oral(
data = dat,
est.method = "nls",
input.ka = 1,
input.cl = 4,
input.vc2cmpt = 70,
input.vp2cmpt = 40,
input.q2cmpt = 10,
input.add = 10
)
# Return only predicted concentrations
Fit_2cmpt_oral(
data = dat,
est.method = "rxSolve",
input.ka = 1,
input.cl = 4,
input.vc2cmpt = 70,
input.vp2cmpt = 40,
input.q2cmpt = 4,
input.add = 10,
return.pred.only = TRUE
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.