The function uses a concentration observed within the first 20% of the elimination
half-life after dosing as the early point for estimating the volume of distribution.
$$Vd = \frac{\text{Dose}}{C_0}$$
For infusion:
$$Vd = \frac{\text{Rate} \times \min(\text{TIME}, \text{durationobs})}{C_0}$$
Here, \(C_0\) represents the early concentration observed within the first 20%
of the elimination half-life after dosing, which is used as an approximation of
the initial concentration for estimating volume of distribution (Vd).
TIME refers to time after dose; durationobs is the actual infusion duration.
When half_life is not provided, it is estimated from pooled data using
the functions get_pooled_data() and get_hf().