| eval_perf_1cmpt | R Documentation |
Computes predictive error metrics by comparing simulated and observed concentration–time data using specified pharmacokinetic parameters and dosing route.
eval_perf_1cmpt(
dat,
est.method = "rxSolve",
ka = NULL,
cl = NULL,
vd = NULL,
route = c("bolus", "infusion", "oral")
)
dat |
A data frame containing raw time–concentration data in the standard nlmixr2 format. |
est.method |
Estimation method passed to the fitting function.
Defaults to using |
ka |
Absorption rate constant. |
cl |
Clearance value. |
vd |
Volume of distribution. |
route |
A character string indicating the route of administration.
Must be one of |
Internally selects the appropriate one-compartment model fitting function, using
Fit_1cmpt_oral() for oral administration and Fit_1cmpt_iv() for intravenous administration.
Predictive performance is quantified using the metrics.() function.
A numeric vector containing absolute prediction error, mean absolute error, mean absolute percentage error, root mean square error, and relative root mean square error.
Fit_1cmpt_oral, Fit_1cmpt_iv, metrics.
eval_perf_1cmpt(
dat = Oral_1CPT,
est.method = "rxSolve",
ka = 1,
cl = 4,
vd = 70,
route = "oral"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.