Learn R Programming

nlmixr2autoinit (version 1.0.0)

mark_dose_number: Mark dose number

Description

Assigns sequential dose numbers based on dosing events (EVID) within each subject.

Usage

mark_dose_number(dat)

Value

A modified data frame with an added column named dose_number, indicating the sequential dose count within each subject and reset group.

Arguments

dat

A data frame containing raw time–concentration data in the standard nlmixr2 format.

Author

Zhonghui Huang

Examples

Run this code
mark_dose_number(Bolus_1CPT)
mark_dose_number(Infusion_1CPT)
mark_dose_number(Oral_1CPT)

Run the code above in your browser using DataLab