powered by
Assigns sequential dose numbers based on dosing events (EVID) within each subject.
mark_dose_number(dat)
A modified data frame with an added column named dose_number, indicating the sequential dose count within each subject and reset group.
A data frame containing raw time–concentration data in the standard nlmixr2 format.
Zhonghui Huang
mark_dose_number(Bolus_1CPT) mark_dose_number(Infusion_1CPT) mark_dose_number(Oral_1CPT)
Run the code above in your browser using DataLab