Learn R Programming

nlmixr2autoinit (version 1.0.0)

run_npd_1cmpt_oral: Run and evaluate a one-compartment oral model

Description

Fits a one-compartment oral pharmacokinetic model using a naive pooled data approach and evaluates model performance based on prediction error metrics.

Usage

run_npd_1cmpt_oral(
  dat,
  est.method = "nls",
  input.ka = exp(1),
  input.cl = exp(1),
  input.vd = exp(1),
  input.add = 1
)

Value

A list containing the fitted parameter estimates and prediction error metrics.

Arguments

dat

A data frame containing raw time–concentration data in standard nlmixr2 format.

est.method

Estimation method used in nlmixr2. Defaults to "nls".

input.ka

Initial estimate for the absorption rate constant (Ka). Defaults to exp(1), corresponding to a log-scale value of 1.

input.cl

Initial estimate for clearance (CL). Defaults to exp(1), corresponding to a log-scale value of 1.

input.vd

Initial estimate for volume of distribution (Vd). Defaults to exp(1), corresponding to a log-scale value of 1.

input.add

Additive error term. Defaults to 1.

Author

Zhonghui Huang

Details

Rows with EVID == 2 are excluded before model fitting. The model is fitted using Fit_1cmpt_oral, and prediction-based metrics are calculated to assess performance.

See Also

Fit_1cmpt_oral

Examples

Run this code
# \donttest{
run_npd_1cmpt_oral(dat = Oral_1CPT, input.ka = 1, input.cl = 4, input.vd = 70)
 # }

Run the code above in your browser using DataLab