Learn R Programming

nlmixr2autoinit (version 1.0.0)

run_npd_2cmpt_iv: Run and evaluate a two-compartment IV model

Description

Fits a two-compartment intravenous pharmacokinetic model using a naive pooled data approach and evaluates model performance based on prediction error metrics.

Usage

run_npd_2cmpt_iv(
  dat,
  est.method = "nls",
  input.cl = exp(1),
  input.vc2cmpt = exp(1),
  input.vp2cmpt = exp(1),
  input.q2cmpt = exp(1),
  input.add = 1
)

Value

A list containing parameter estimates and prediction error metrics.

Arguments

dat

A data frame containing raw time–concentration data in standard nlmixr2 format.

est.method

Estimation method used in nlmixr2. Defaults to "nls".

input.cl

Initial estimate for clearance (CL). Defaults to exp(1), corresponding to a log-scale value of 1.

input.vc2cmpt

Initial estimate for central compartment volume (Vc). Defaults to exp(1), corresponding to a log-scale value of 1.

input.vp2cmpt

Initial estimate for peripheral compartment volume (Vp). Defaults to exp(1), corresponding to a log-scale value of 1.

input.q2cmpt

Initial estimate for intercompartmental clearance (Q). Defaults to exp(1), corresponding to a log-scale value of 1.

input.add

Additive error term. Defaults to 1.

Author

Zhonghui Huang

Details

Rows with EVID == 2 are excluded prior to model fitting. The model is fitted using Fit_2cmpt_iv, and prediction-based metrics are calculated to assess performance.

See Also

Fit_2cmpt_iv

Examples

Run this code
# \donttest{
run_npd_2cmpt_iv(dat = Bolus_2CPT,
                           input.cl = 4,
                           input.vc2cmpt = 35,
                           input.vp2cmpt = 35,
                           input.q2cmpt = 4)
# }

Run the code above in your browser using DataLab