Learn R Programming

nlmixr2autoinit (version 1.0.0)

run_npd_2cmpt_oral: Run and evaluate a two-compartment oral model

Description

Fits a two-compartment oral pharmacokinetic model using a naive pooled data approach and evaluates model performance using prediction error metrics.

Usage

run_npd_2cmpt_oral(
  dat,
  est.method = "nls",
  input.ka = exp(1),
  input.cl = exp(1),
  input.vc2cmpt = exp(1),
  input.vp2cmpt = exp(1),
  input.q2cmpt = exp(1),
  input.add = 1
)

Value

A list containing the fitted parameter estimates and prediction error metrics.

Arguments

dat

A data frame containing time–concentration data in standard nlmixr2 format.

est.method

Estimation method used in nlmixr2. Defaults to "nls".

input.ka

Initial estimate for the absorption rate constant (Ka). Defaults to exp(1), corresponding to a log-scale value of 1.

input.cl

Initial estimate for clearance (CL). Defaults to exp(1) , corresponding to a log-scale value of 1.

input.vc2cmpt

Initial estimate for the central volume of distribution (Vc). Defaults to exp(1), corresponding to a log-scale value of 1.

input.vp2cmpt

Initial estimate for the peripheral volume of distribution (Vp). Defaults to exp(1), corresponding to a log-scale value of 1.

input.q2cmpt

Initial estimate for intercompartmental clearance (Q). Defaults to exp(1), corresponding to a log-scale value of 1.

input.add

Additive error term. Defaults to 1.

Author

Zhonghui Huang

Details

Rows with EVID == 2 are excluded before fitting the model. The model is fitted using Fit_2cmpt_oral, and prediction-based metrics are computed to evaluate performance.

See Also

Fit_2cmpt_oral

Examples

Run this code
# \donttest{
run_npd_2cmpt_oral(
  dat = Oral_2CPT,
  input.ka = 1,
  input.cl = 4,
  input.vc2cmpt = 35,
  input.vp2cmpt = 35,
  input.q2cmpt = 4
)
# }

Run the code above in your browser using DataLab