run_npd_3cmpt_iv: Run and evaluate a three-compartment IV model

View source: R/run_modelfit.R

run_npd_3cmpt_ivR Documentation

Run and evaluate a three-compartment IV model

Description

Fits a three-compartment intravenous pharmacokinetic model using a naive pooled data approach and evaluates model performance based on prediction error metrics.

Usage

run_npd_3cmpt_iv(
  dat,
  est.method = "nls",
  input.cl = exp(1),
  input.vc3cmpt = exp(1),
  input.vp3cmpt = exp(1),
  input.vp23cmpt = exp(1),
  input.q3cmpt = exp(1),
  input.q23cmpt = exp(1),
  input.add = 1
)

Arguments

dat

A data frame containing raw intravenous concentration–time data in standard nlmixr2 format.

est.method

Estimation method used in nlmixr2. Defaults to "nls".

input.cl

Initial estimate for clearance (CL). Defaults to exp(1), corresponding to a log-scale value of 1.

input.vc3cmpt

Initial estimate for central volume of distribution (Vc). Defaults to exp(1), corresponding to a log-scale value of 1.

input.vp3cmpt

Initial estimate for first peripheral volume (Vp1). Defaults to exp(1), corresponding to a log-scale value of 1.

input.vp23cmpt

Initial estimate for second peripheral volume (Vp2). Defaults to exp(1), corresponding to a log-scale value of 1.

input.q3cmpt

Initial estimate for intercompartmental clearance between central and first peripheral compartments (Q1). Defaults to exp(1), corresponding to a log-scale value of 1.

input.q23cmpt

Initial estimate for intercompartmental clearance between central and second peripheral compartments (Q2). Defaults to exp(1), corresponding to a log-scale value of 1.

input.add

Additive error term. Defaults to 1.

Details

Rows with EVID == 2 are excluded prior to model fitting. The model is fitted using Fit_3cmpt_iv, and prediction-based metrics are calculated to evaluate performance.

Value

A list containing fitted parameter estimates and model prediction error metrics.

Author(s)

Zhonghui Huang

See Also

Fit_3cmpt_iv

Examples


run_npd_3cmpt_iv(
  dat = Bolus_2CPT,
  input.cl = 4,
  input.vc3cmpt = 70,
  input.vp3cmpt = 40,
  input.vp23cmpt = 10,
  input.q3cmpt = 4,
  input.q23cmpt = 4
)



nlmixr2autoinit documentation built on Nov. 14, 2025, 1:07 a.m.